@@ -163,6 +163,9 @@ CLIMATE_ITEMS = {
     23834: "Tropical cyclones within 50 km, Saffir-Simpson Category 3-5",
     23835: "Tropical cyclones within 50 km, Saffir-Simpson Category 4-5",
     23836: "Tropical cyclones within 50 km, Saffir-Simpson Category 5",
+    25884: "Ocean",
+    25885: "Sea surface",
+    26971: "Heat stress"
 }
 
 CLIMATE_METRICS = {
@@ -243,6 +246,17 @@ CLIMATE_METRICS = {
     15853620: "Frequency of events",
     15853621: "Return time of events",
     15853622: "Probability of at least one event per year",
+    15853856: "Sea surface height",
+    15853857: "Mean sea level",
+    15853884: "Change since 2015, 1st percentile",
+    15853883: "Change since 2015, 5th percentile",
+    15853858: "Change since 2015, 50th percentile",
+    15853859: "Change since 2015, 95th percentile",
+    15853860: "Change since 2015, 99th percentile",
+    15853878: "Temperature Humidity Index (max)",
+    15853879: "Temperature Humidity Index (min)",
+    15853880: "Heat Index (max)",
+    15853881: "Heat Index (min)"
 }
 
 CLIMATE_SOURCES = [
@@ -291,5 +305,11 @@ CLIMATE_SOURCES = [
     309,
     319,
     320,
+    322,
+    323,
+    324,
+    325,
+    326,
+    327
 ]
 CMIP6_SOURCES = [178, 189, 190, 191, 192, 300, 301, 302, 303, 304, 305, 306, 307, 308, 309]
